@@ -1,4 +1,4 @@
 from .glob import set_main_controller
-from .core import CommandRunner, HpcRunner, bag, init
+from .core import CommandRunner, HpcRunner, HpcRunner_slurm, bag, init
 from .task import Task
 #from . import cli
\ No newline at end of file
